package net.sf.basedb.clients.web;

import net.sf.basedb.core.AnnotationTypeCategory;
import net.sf.basedb.core.ItemContext;
import net.sf.basedb.core.ItemContext.AddFilter;
import net.sf.basedb.core.ItemSubtype;

/**
	Helper class for changing the current subcontext.
	@see Base#changeCurrentSubContext(net.sf.basedb.core.DbControl, net.sf.basedb.core.Item, javax.servlet.ServletRequest)
	@since 3.20
*/
public class SubContext 
{

	private final String name;
	private final ItemSubtype subtype;
	private final AnnotationTypeCategory category;
	private final boolean change;
	private final AddFilter addFilter;
	
	/**
		Create an instance that doesn't change the current item context.
		@param name The name of the current subcontext
	*/
	public SubContext(String name)
	{
		this.name = name;
		this.subtype = null;
		this.category = null;
		this.change = false;
		this.addFilter = AddFilter.NO;
	}
	
	/**
		Create an instance that changes the current item context.
	*/
	public SubContext(String name, ItemSubtype subtype, AnnotationTypeCategory category, AddFilter addFilter)
	{
		this.name = name;
		this.subtype = subtype;
		this.category = category;
		this.change = true;
		this.addFilter = addFilter;
	}
	
	/**
		Apply the new subcontext to the given item context. 
		@see ItemContext#setItemSubtype(ItemSubtype)
		@see ItemContext#setSubCategory(AnnotationTypeCategory, AddFilter)
	*/
	public void applyToContext(ItemContext cc)
	{
		if (change)
		{
			cc.setItemSubtype(subtype);
			cc.setSubCategory(category, addFilter);
		}
	}
	
	/**
		Is the context changed or not?
	*/
	public boolean isChange()
	{
		return change;
	}
	
	/**
		Get the name of the subcontext.
	*/
	public String getName()
	{
		return name;
	}
	
	/**
		The new item subtype. Note! Always null if there is no context change.
	*/
	public ItemSubtype getItemSubtype()
	{
		return subtype;
	}
	
	/**
		The new sub-category.  Note! Always null if there is no context change.
	*/
	public AnnotationTypeCategory getSubCategory()
	{
		return category;
	}
	
	public AddFilter getAddFilter()
	{
		return addFilter;
	}
	
}
