/**
	$Id: OnSaveRenderer.java 8144 2023-04-21 11:43:05Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.edit;

import net.sf.basedb.util.extensions.AbstractRenderer;
import net.sf.basedb.util.extensions.Extension;

/**
	Renderer implementations for OnSaveAction:s. 
	
	@author Nicklas
	@since 2.17
	@see OnSaveAction
	@base.modified $Date: 2023-04-21 13:43:05 +0200 (Fri, 21 Apr 2023) $
*/
public abstract class OnSaveRenderer
	extends AbstractRenderer<OnSaveAction>
{

	/**
		Renderer that calls the {@link OnSaveAction#onSave()}
		method.
	*/
	public static final OnSaveRenderer ON_SAVE = new OnSaveRenderer()
	{
		@Override
		public void render(OnSaveAction action, Extension<? extends OnSaveAction> ext)
		{
			action.onSave();
		}
	};

	/**
		Renderer that calls the {@link OnSaveAction#onCommit()}
		method.
	*/
	public static final OnSaveRenderer ON_COMMIT = 
		new OnSaveRenderer()
		{
			@Override
			public void render(OnSaveAction action, Extension<? extends OnSaveAction> ext)
			{
				action.onCommit();
			}
		};

	/**
		Renderer that calls the {@link OnSaveAction#onRollback(Exception)}
		method.
	*/
	public static final OnSaveRenderer onRollback(final Exception ex)
	{
		return new OnSaveRenderer()
		{
			@Override
			public void render(OnSaveAction action, Extension<? extends OnSaveAction> ext)
			{
				action.onRollback(ex);
			}
		};
	}

	protected OnSaveRenderer()
	{}
	
}
