/*
	$Id: AnnotationTypeCategoryData.java 8263 2024-10-18 11:41:27Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg, Dominic Oyeniran

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.Set;

/**
	This data layer class holds information about annotation type categories.

	@author Dominic Oyeniran
	@version 2.0
	@see net.sf.basedb.core.AnnotationTypeCategory
	@see <a href="../../../../../../html/developer/api/data_api.annotations.html">Developer documentation: Annotations</a>
	@base.modified $Date: 2006-04-18 10:48:02 +0100 (Tue, 18 Apr 2006) $
	@hibernate.class table="`AnnotationTypeCategories`" lazy="false"
*/
public class AnnotationTypeCategoryData  
	extends CommonData 
	implements RegisteredData

{
	public AnnotationTypeCategoryData() 
	{}
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private String shortName;
	/**
		A short name can be used in some places instead of the normal name.
		@since 3.20
		@hibernate.property column="`short_name`" type="string" length="255" not-null="false"
	*/
	public String getShortName()
	{
		return shortName;
	}
	public void setShortName(String shortName)
	{
		this.shortName = shortName;
	}
	
	private ItemSubtypeData subtype;
	/**
		The subtype that is linked to this category of annotations.
		@since 3.20
		@hibernate.many-to-one column="`subtype_id`" not-null="false" outer-join="false"
	*/
	public ItemSubtypeData getItemSubtype()
	{
	   return subtype;
	}
	public void setItemSubtype(ItemSubtypeData subtype)
	{
	   this.subtype = subtype;
	}
	
	private ParameterValueData<?> subCategoryValues;
	/**
		The values to match for subcategories. The values should be
		selected from the annotation type on the item subtype.
		@since 3.20
		@hibernate.many-to-one column="`subcategoryvalues_id`" not-null="false" cascade="all" unique="true"
	*/
	public ParameterValueData<?> getSubCategoryValues()
	{
		return subCategoryValues;
	}
	public void setSubCategoryValues(ParameterValueData<?> subCategoryValues)
	{
		this.subCategoryValues = subCategoryValues;
	}
	
	private Set<AnnotationTypeData> annotationTypes;
	/**
		This is the inverse end.
		@see AnnotationTypeData#getCategories()
		@hibernate.set table="`CategorisedAnnotationTypes`" lazy="true" 
		@hibernate.collection-key column="`category_id`"
		@hibernate.collection-many-to-many column="`annotationtype_id`" class="net.sf.basedb.core.data.AnnotationTypeData"
	*/
	public Set<AnnotationTypeData> getAnnotationTypes() 
	{
		return annotationTypes;
	}

	void setAnnotationTypes(Set<AnnotationTypeData> annotationTypes) 
	{
		this.annotationTypes = annotationTypes;
	}

}

